import { forwardRef, useEffect, useRef, useState } from 'react'
import Taro, { useShareAppMessage } from '@tarojs/taro'
import { useDidHide, useDidShow } from '@tarojs/taro'
import { observer, inject } from 'mobx-react'
import { View } from '@tarojs/components'
import './index.less'
//==========components组件引用========================
import TopNavBar from '@src/components/TopNavBar/index'
import ScrollViewHoc from '@src/components/ScrollView'
import BookboxRowBig from '@src/components/PupPetry/BookBox/BookboxRowBig'
import BookTypeTabs from '@src/components/PupPetry/BookTypeTabs'
import Empty from '@src/components/Empty'
import { Store } from '@src/app'
import useApi from '@src/Hook/useApi'
import { getBookCategoryList } from '@src/server/classify'
import { share } from '@src/utils'


interface Props {
    store: Store;
}

const Index = forwardRef((props: Props) => {
    const { bookStore, classifyStore, indexStore } = props.store
    const { getBookPageList } = useApi()
    const [pageShow, setPageShow] = useState(false)//防止小程序切换页面组件不会被真实卸载,阻止不必要的操作
    const [isFixed, setIsFixed] = useState(false)
    const [open, setOpen] = useState(false)
    const [showEmpty, setShowEmpty] = useState(false)
    // 获取分类列表
    useEffect(() => {
        if (pageShow) {
            let { workDirection } = bookStore
            getBookCategoryList(workDirection)
        }
    }, [bookStore.workDirection, pageShow]); // Dependency array, runs effect only once on mount and unmount
    //获取书籍列表
    useEffect(() => {
        if (pageShow) {
            let { workDirection } = bookStore
            let { categoryId } = classifyStore
            showEmpty && setShowEmpty(false)
            categoryId.id != 0 && classifyStore.categoryId && getList({ workDirection, categoryId: categoryId.id, pageNum: 1, pageSize: 10 }).then((res: any) => {
                if (res?.data?.data?.total === 0) {
                   !showEmpty && setShowEmpty(true)
                }
            })
        }
    }, [bookStore.workDirection, classifyStore.categoryId, pageShow])
    // 使用 useDidShow 代替 onShow
    useDidShow(() => {
        setPageShow(true)
    });
    // 使用 useDidHide 如果需要在页面隐藏时做一些处理
    useDidHide(() => {
        setPageShow(false)
        bookStore.setData({ bookList: [] })
    });
    //上拉刷新
    const refresh = async () => {
        let { workDirection } = bookStore
        let { categoryId } = classifyStore
        getList({ workDirection, categoryId: categoryId.id, pageNum: 1, pageSize: 10 })
    }
    //下拉加载
    const load = () => {
        return new Promise((resolve, reject) => {
            let { size, total, records } = bookStore.bookList
            let pageSize = size + 10
            let { workDirection } = bookStore
            let { categoryId } = classifyStore
            if (records?.length >= total) {
                Taro.showToast({
                    title: '没有更多了~~',
                    duration: 2000,
                    icon: 'none'
                })
                reject()
                return
            } else {
                getList({ workDirection, categoryId: categoryId.id, pageNum: 1, pageSize }).then(res => {
                    console.log("Res", res)
                    resolve(true)
                })
            }
        })
    }
    const getList = async (params) => {
        return getBookPageList(params)
    }
    // 分享
    useShareAppMessage(async () => {
        // 获取当前页面栈
        const pages = Taro.getCurrentPages()
        // 获取栈顶的页面，即当前页面
        const currentPage = pages[pages.length - 1]
        // 获取页面的路径和参数
        const route = currentPage.route // 页面路径
        if (route) {
            let shareInfo = await share({ pagePath: route })
            let { sharePicUrl, shareTitles, pageName, pagePath } = shareInfo
            return {
                title: shareTitles || app.appInfo?.appName + '-' + pageName,
                path: pagePath || undefined,
                imageUrl: sharePicUrl || undefined
            }
        }
        return {}
    })
    return (

        <View className='index'>
            {bookStore?.classifyData?.length > 0 && <View style={isFixed ? { position: 'fixed', background: "#fff" } : { background: "#fff" }} className='classList'>
                <BookTypeTabs open={open} onCallback={setOpen} typeValue={bookStore?.classifyData} typeTabIndex={classifyStore.categoryId} workDirection={bookStore.workDirection} ></BookTypeTabs>
            </View>}
            <ScrollViewHoc callback={(top) => {
                if (top > 100 && open) {
                    setOpen(false)
                }
                if (top < 100 && !open) {
                    setOpen(true)
                }
            }} load={load} refresh={refresh} reloadState={open} filterClassName='.classList' navHeight={indexStore.navHeight}>
                <View className='w  row for_top1 pd_btm'>
                    {
                        bookStore?.bookList?.records?.length > 0 && bookStore?.bookList?.records?.map((item, index) => {
                            return <>
                                <View key={item.bookId} ><BookboxRowBig {...item} /></View>
                            </>
                        })
                    }
                    {
                        showEmpty && <Empty />
                    }
                </View>
            </ScrollViewHoc>
        </View>

    );
});
export default TopNavBar(inject('store')(observer(Index)), {
    tab: true,
    tabVal: [{ value: 0, text: "男生" }, { value: 1, text: "女生" }],
    backgroundColor: '#fff',
    color: "#333",
    search: false,
});
